@@ -1,5 +1,6 @@
 use crate::control_flow::ControlFlow;
 use crate::diagnostic::{LintDiagnostic, Position, Range};
+use crate::handler::TraverseFlow;
 use crate::ignore_directives::{
   CodeStatus, FileIgnoreDirective, LineIgnoreDirective,
 };
@@ -12,18 +13,42 @@ use std::time::Instant;
 use swc_common::comments::Comment;
 use swc_common::{SourceMap, Span, SyntaxContext};
 
+/// `Context` stores data needed while performing all lint rules to a file.
 pub struct Context<'view> {
+  /// File name on which the lint rule is run
   file_name: String,
+
+  /// Stores diagnostics that are generated while linting
   diagnostics: Vec<LintDiagnostic>,
+
+  /// Stores codes of plugin (user-defined) rules
   plugin_codes: HashSet<String>,
+
+  /// `SourceMap` of swc
   source_map: Rc<SourceMap>,
+
+  /// The AST view of the program, which for example can be used for getting
+  /// comments
   program: AstView::Program<'view>,
+
+  /// File-level ignore directive (`deno-lint-ignore-file`)
   file_ignore_directive: Option<FileIgnoreDirective>,
-  /// key is line number
+
+  /// The map that stores line-level ignore directives (`deno-lint-ignore`).
+  /// The key of the map is line number.
   line_ignore_directives: HashMap<usize, LineIgnoreDirective>,
+
+  /// Scope analysis result
   scope: Scope,
+
+  /// Control-flow analysis result
   control_flow: ControlFlow,
+
+  /// The `SyntaxContext` of the top level
   top_level_ctxt: SyntaxContext,
+
+  /// A value to control whether the node's children will be traversed or not.
+  traverse_flow: TraverseFlow,
 }
 
 impl<'view> Context<'view> {
@@ -49,6 +74,7 @@ impl<'view> Context<'view> {
       top_level_ctxt,
       diagnostics: Vec::new(),
       plugin_codes: HashSet::new(),
+      traverse_flow: TraverseFlow::default(),
     }
   }
   pub fn file_name(&self) -> &str {
@@ -91,6 +117,14 @@ impl<'view> Context<'view> {
     self.top_level_ctxt
   }
 
+  pub(crate) fn traverse_flow(&self) -> TraverseFlow {
+    self.traverse_flow
+  }
+
+  pub(crate) fn traverse_flow_mut(&mut self) -> &mut TraverseFlow {
+    &mut self.traverse_flow
+  }
+
   pub fn all_comments(&self) -> impl Iterator<Item = &'view Comment> {
     self
       .program
@@ -150,6 +184,9 @@ impl<'view> Context<'view> {
     filtered
   }
 
+  /// Lint rule implementation for `ban-unused-ignore`.
+  /// This should be run after all normal rules have been finished because this
+  /// works for diagnostics reported by other rules.
   pub(crate) fn ban_unused_ignore(
     &self,
     specified_rules: &[Box<dyn LintRule>],
@@ -211,6 +248,10 @@ impl<'view> Context<'view> {
     diagnostics
   }
 
+  /// Lint rule implementation for `ban-unknown-rule-code`.
+  /// This should be run after all normal rules have been finished because
+  /// currently we collect the rule codes of plugins as they are run and thus
+  /// there's no way of knowing what are the "known" rule codes beforehand.
   pub(crate) fn ban_unknown_rule_code(&self) -> Vec<LintDiagnostic> {
     let builtin_all_rule_codes: HashSet<&'static str> =
       get_all_rules().into_iter().map(|r| r.code()).collect();
