@@ -5,8 +5,10 @@ use dprint_swc_ecma_ast_view::Program as ProgramView;
 pub mod adjacent_overload_signatures;
 pub mod ban_ts_comment;
 pub mod ban_types;
+pub mod ban_unknown_rule_code;
 pub mod ban_untagged_ignore;
 pub mod ban_untagged_todo;
+pub mod ban_unused_ignore;
 pub mod camelcase;
 pub mod constructor_super;
 pub mod default_param_last;
@@ -81,6 +83,7 @@ pub mod no_with;
 pub mod prefer_as_const;
 pub mod prefer_const;
 pub mod prefer_namespace_keyword;
+pub mod prefer_primordials;
 pub mod require_await;
 pub mod require_yield;
 pub mod single_var_declarator;
@@ -144,8 +147,10 @@ pub fn get_all_rules() -> Vec<Box<dyn LintRule>> {
     adjacent_overload_signatures::AdjacentOverloadSignatures::new(),
     ban_ts_comment::BanTsComment::new(),
     ban_types::BanTypes::new(),
+    ban_unknown_rule_code::BanUnknownRuleCode::new(),
     ban_untagged_ignore::BanUntaggedIgnore::new(),
     ban_untagged_todo::BanUntaggedTodo::new(),
+    ban_unused_ignore::BanUnusedIgnore::new(),
     camelcase::Camelcase::new(),
     constructor_super::ConstructorSuper::new(),
     default_param_last::DefaultParamLast::new(),
@@ -220,6 +225,7 @@ pub fn get_all_rules() -> Vec<Box<dyn LintRule>> {
     prefer_as_const::PreferAsConst::new(),
     prefer_const::PreferConst::new(),
     prefer_namespace_keyword::PreferNamespaceKeyword::new(),
+    prefer_primordials::PreferPrimordials::new(),
     require_await::RequireAwait::new(),
     require_yield::RequireYield::new(),
     single_var_declarator::SingleVarDeclarator::new(),
