@@ -49,8 +49,8 @@ impl LintRule for ExplicitModuleBoundaryTypes {
   ) {
     let mut visitor = ExplicitModuleBoundaryTypesVisitor::new(context);
     match program {
-      ProgramRef::Module(ref m) => visitor.visit_module(m, &DUMMY_NODE),
-      ProgramRef::Script(ref s) => visitor.visit_script(s, &DUMMY_NODE),
+      ProgramRef::Module(m) => visitor.visit_module(m, &DUMMY_NODE),
+      ProgramRef::Script(s) => visitor.visit_script(s, &DUMMY_NODE),
     }
   }
 
@@ -136,7 +136,7 @@ impl<'c, 'view> ExplicitModuleBoundaryTypesVisitor<'c, 'view> {
       );
     }
     for pat in &arrow.params {
-      self.check_pat(&pat);
+      self.check_pat(pat);
     }
   }
 
