@@ -43,8 +43,8 @@ impl LintRule for NoExtraSemi {
   ) {
     let mut visitor = NoExtraSemiVisitor::new(context);
     match program {
-      ProgramRef::Module(ref m) => m.visit_with(&DUMMY_NODE, &mut visitor),
-      ProgramRef::Script(ref s) => s.visit_with(&DUMMY_NODE, &mut visitor),
+      ProgramRef::Module(m) => m.visit_with(&DUMMY_NODE, &mut visitor),
+      ProgramRef::Script(s) => s.visit_with(&DUMMY_NODE, &mut visitor),
     }
   }
 
