@@ -36,10 +36,64 @@ impl LintRule for NoRedeclare {
       bindings: Default::default(),
     };
     match program {
-      ProgramRef::Module(ref m) => visitor.visit_module(m, &DUMMY_NODE),
-      ProgramRef::Script(ref s) => visitor.visit_script(s, &DUMMY_NODE),
+      ProgramRef::Module(m) => visitor.visit_module(m, &DUMMY_NODE),
+      ProgramRef::Script(s) => visitor.visit_script(s, &DUMMY_NODE),
     }
   }
+
+  fn docs(&self) -> &'static str {
+    r#"Disallows redeclaration of variables, functions, parameters with the same
+name.
+
+JavaScript allows us to redeclare variables with the same name using `var`, but
+redeclaration should not be used since it can make variables hard to trace.
+
+In addition, this lint rule disallows redeclaration using `let` or `const` as
+well, although ESLint allows. This is useful because we can notice a syntax
+error before actually running the code.
+
+As for functions and parameters, JavaScript just treats these as runtime errors,
+throwing `SyntaxError` when being run. It's also beneficial to detect this sort
+of errors statically.
+
+### Invalid:
+
+```typescript
+var a = 3;
+var a = 10;
+
+let b = 3;
+let b = 10;
+
+const c = 3;
+const c = 10;
+
+function d() {}
+function d() {}
+
+function e(arg: number) {
+  var arg: number;
+}
+
+function f(arg: number, arg: string) {}
+```
+
+### Valid:
+
+```typescript
+var a = 3;
+function f() {
+  var a = 10;
+}
+
+if (foo) {
+  let b = 2;
+} else {
+  let b = 3;
+}
+```
+"#
+  }
 }
 
 struct NoRedeclareVisitor<'c, 'view> {
@@ -150,6 +204,7 @@ mod tests {
       "var a = 3; var a = 10; var a = 15;": [{col: 15, message: MESSAGE}, {col: 27, message: MESSAGE}],
       "var a; var {a = 0, b: Object = 0} = {};": [{line: 1, col: 12, message: MESSAGE}],
       "var a; var {a = 0, b: globalThis = 0} = {};": [{line: 1, col: 12, message: MESSAGE}],
+      "function f(foo: number, foo: string) {}": [{line: 1, col: 24, message: MESSAGE}],
     }
   }
 }
